@@ -15,6 +15,11 @@ namespace phpbb\db\migration\data\v31x;
 
 class v313rc2 extends \phpbb\db\migration\migration
 {
+	public function effectively_installed()
+	{
+		return phpbb_version_compare($this->config['version'], '3.1.3-RC2', '>=');
+	}
+
 	static public function depends_on()
 	{
 		return array(
